@@ -2,7 +2,7 @@ from enum import Enum
 from serpyco import field
 from dataclasses import dataclass
 from datetime import date, datetime
-from typing import Optional, Generic, TypeVar
+from typing import Optional, Generic, TypeVar, List
 
 from energytt_platform.serialize import Serializable
 
@@ -11,6 +11,9 @@ from energytt_platform.serialize import Serializable
 
 
 class EnergyDirection(Enum):
+    """
+    TODO
+    """
     production = 'production'  # E18
     consumption = 'consumption'  # E17
 
@@ -31,8 +34,27 @@ class Address(Serializable):
     municipality_code: Optional[str] = field(default=None)
     location_description: Optional[str] = field(default=None)
 
+    def __str__(self) -> str:
+        """
+        Creates a string representation of the address.
+        """
+        return self.format()
 
-# -- Date & Time -------------------------------------------------------------
+    def format(self, separator: str = '\n') -> str:
+        """
+        Creates a string representation of the address.
+        """
+        return separator.join(self.parts)
+
+    @property
+    def parts(self) -> List[str]:
+        """
+        TODO
+        """
+        return []
+
+
+# -- Value Ranges ------------------------------------------------------------
 
 
 @dataclass
@@ -60,6 +82,9 @@ TOrderKey = TypeVar('TOrderKey', bound=Enum)
 
 
 class Order(Enum):
+    """
+    TODO
+    """
     asc = 'asc'
     desc = 'desc'
 
@@ -69,8 +94,8 @@ class ResultOrdering(Serializable, Generic[TOrderKey]):
     """
     Ordering of query results.
     """
-    order: Optional[Order] = field(default=None)
     key: Optional[TOrderKey] = field(default=None)
+    order: Order = field(default=Order.asc)
 
     @property
     def asc(self) -> bool:
