@@ -1,4 +1,4 @@
-from energytt_platform.bus import MessageBroker, Message, testing
+from energytt_platform.bus import MessageBroker, Message
 
 
 class TestMessageBroker:
